@@ -462,6 +462,54 @@ class Application(object):
 
         return self.client.request("GET", path, params=query_params, headers=headers, body=body)
 
+    def globals(self, **kwargs):
+        """
+        Updates an application global at the given key
+
+        Authentication:
+        The client must be configured with a valid api
+        access token to call this action. The token
+        must include at least one of the following scopes:
+        all.Application, all.Organization, all.User, application.*, or application.patch.
+
+        Parameters:
+        *  {string} applicationId - ID of the associated application
+        *  {hash} globals - Array of objects containing new application global information (https://api.losant.com/#/definitions/applicationGlobalPatch)
+        *  {string} losantdomain - Domain scope of request (rarely needed)
+        *  {boolean} _actions - Return resource actions in response
+        *  {boolean} _links - Return resource link in response
+        *  {boolean} _embedded - Return embedded resources in response
+
+        Responses:
+        *  200 - Updated application information (https://api.losant.com/#/definitions/application)
+
+        Errors:
+        *  400 - Error if malformed request (https://api.losant.com/#/definitions/error)
+        *  404 - Error if application was not found (https://api.losant.com/#/definitions/error)
+        """
+
+        query_params = {"_actions": "false", "_links": "true", "_embedded": "true"}
+        path_params = {}
+        headers = {}
+        body = None
+
+        if "applicationId" in kwargs:
+            path_params["applicationId"] = kwargs["applicationId"]
+        if "globals" in kwargs:
+            body = kwargs["globals"]
+        if "losantdomain" in kwargs:
+            headers["losantdomain"] = kwargs["losantdomain"]
+        if "_actions" in kwargs:
+            query_params["_actions"] = kwargs["_actions"]
+        if "_links" in kwargs:
+            query_params["_links"] = kwargs["_links"]
+        if "_embedded" in kwargs:
+            query_params["_embedded"] = kwargs["_embedded"]
+
+        path = "/applications/{applicationId}/globals".format(**path_params)
+
+        return self.client.request("PATCH", path, params=query_params, headers=headers, body=body)
+
     def mqtt_publish_message(self, **kwargs):
         """
         Publishes the given message to the given MQTT topic
