@@ -35,6 +35,8 @@ from .application_certificate import ApplicationCertificate
 from .application_certificate_authorities import ApplicationCertificateAuthorities
 from .application_certificate_authority import ApplicationCertificateAuthority
 from .application_certificates import ApplicationCertificates
+from .application_dashboard import ApplicationDashboard
+from .application_dashboards import ApplicationDashboards
 from .application_key import ApplicationKey
 from .application_keys import ApplicationKeys
 from .application_template import ApplicationTemplate
@@ -99,7 +101,7 @@ class Client(object):
 
     User API for accessing Losant data
 
-    Built For Version 1.18.0
+    Built For Version 1.19.0
     """
 
     def __init__(self, auth_token=None, url="https://api.losant.com"):
@@ -112,6 +114,8 @@ class Client(object):
         self.application_certificate_authorities = ApplicationCertificateAuthorities(self)
         self.application_certificate_authority = ApplicationCertificateAuthority(self)
         self.application_certificates = ApplicationCertificates(self)
+        self.application_dashboard = ApplicationDashboard(self)
+        self.application_dashboards = ApplicationDashboards(self)
         self.application_key = ApplicationKey(self)
         self.application_keys = ApplicationKeys(self)
         self.application_template = ApplicationTemplate(self)
@@ -174,7 +178,7 @@ class Client(object):
             params = {}
 
         headers["Accept"] = "application/json"
-        headers["Accept-Version"] = "^1.18.0"
+        headers["Accept-Version"] = "^1.19.0"
         if self.auth_token:
             headers["Authorization"] = "Bearer {0}".format(self.auth_token)
 
