@@ -34,6 +34,60 @@ class Devices(object):
     def __init__(self, client):
         self.client = client
 
+    def attribute_names(self, **kwargs):
+        """
+        Gets the attribute names that match the given query. Maximum 1K returned.
+
+        Authentication:
+        The client must be configured with a valid api
+        access token to call this action. The token
+        must include at least one of the following scopes:
+        all.Application, all.Application.read, all.Organization, all.Organization.read, all.User, all.User.read, devices.*, or devices.attributeNames.
+
+        Parameters:
+        *  {string} applicationId - ID associated with the application
+        *  {hash} query - Device filter JSON object (https://api.losant.com/#/definitions/advancedDeviceQuery)
+        *  {hash} dataType - Filter the devices by the given attribute data type or types (https://api.losant.com/#/definitions/deviceAttributeDataTypeFilter)
+        *  {string} startsWith - Filter attributes down to those that have names starting with the given string. Case insensitive.
+        *  {string} losantdomain - Domain scope of request (rarely needed)
+        *  {boolean} _actions - Return resource actions in response
+        *  {boolean} _links - Return resource link in response
+        *  {boolean} _embedded - Return embedded resources in response
+
+        Responses:
+        *  200 - The matching attribute names (https://api.losant.com/#/definitions/attributeNamesResponse)
+
+        Errors:
+        *  400 - Error if malformed request (https://api.losant.com/#/definitions/error)
+        *  404 - Error if application was not found (https://api.losant.com/#/definitions/error)
+        """
+
+        query_params = {"_actions": "false", "_links": "true", "_embedded": "true"}
+        path_params = {}
+        headers = {}
+        body = None
+
+        if "applicationId" in kwargs:
+            path_params["applicationId"] = kwargs["applicationId"]
+        if "query" in kwargs:
+            query_params["query"] = json.dumps(kwargs["query"])
+        if "dataType" in kwargs:
+            query_params["dataType"] = kwargs["dataType"]
+        if "startsWith" in kwargs:
+            query_params["startsWith"] = kwargs["startsWith"]
+        if "losantdomain" in kwargs:
+            headers["losantdomain"] = kwargs["losantdomain"]
+        if "_actions" in kwargs:
+            query_params["_actions"] = kwargs["_actions"]
+        if "_links" in kwargs:
+            query_params["_links"] = kwargs["_links"]
+        if "_embedded" in kwargs:
+            query_params["_embedded"] = kwargs["_embedded"]
+
+        path = "/applications/{applicationId}/devices/attributeNames".format(**path_params)
+
+        return self.client.request("GET", path, params=query_params, headers=headers, body=body)
+
     def delete(self, **kwargs):
         """
         Delete devices
@@ -409,3 +463,108 @@ class Devices(object):
 
         return self.client.request("POST", path, params=query_params, headers=headers, body=body)
 
+    def tag_keys(self, **kwargs):
+        """
+        Gets the unique tag keys for devices that match the given query. Maximum 1K returned.
+
+        Authentication:
+        The client must be configured with a valid api
+        access token to call this action. The token
+        must include at least one of the following scopes:
+        all.Application, all.Application.read, all.Organization, all.Organization.read, all.User, all.User.read, devices.*, or devices.tagKeys.
+
+        Parameters:
+        *  {string} applicationId - ID associated with the application
+        *  {hash} query - Device filter JSON object (https://api.losant.com/#/definitions/advancedDeviceQuery)
+        *  {string} startsWith - Filter keys down to those that start with the given string. Case insensitive.
+        *  {string} losantdomain - Domain scope of request (rarely needed)
+        *  {boolean} _actions - Return resource actions in response
+        *  {boolean} _links - Return resource link in response
+        *  {boolean} _embedded - Return embedded resources in response
+
+        Responses:
+        *  200 - The matching tag keys (https://api.losant.com/#/definitions/tagKeysResponse)
+
+        Errors:
+        *  400 - Error if malformed request (https://api.losant.com/#/definitions/error)
+        *  404 - Error if application was not found (https://api.losant.com/#/definitions/error)
+        """
+
+        query_params = {"_actions": "false", "_links": "true", "_embedded": "true"}
+        path_params = {}
+        headers = {}
+        body = None
+
+        if "applicationId" in kwargs:
+            path_params["applicationId"] = kwargs["applicationId"]
+        if "query" in kwargs:
+            query_params["query"] = json.dumps(kwargs["query"])
+        if "startsWith" in kwargs:
+            query_params["startsWith"] = kwargs["startsWith"]
+        if "losantdomain" in kwargs:
+            headers["losantdomain"] = kwargs["losantdomain"]
+        if "_actions" in kwargs:
+            query_params["_actions"] = kwargs["_actions"]
+        if "_links" in kwargs:
+            query_params["_links"] = kwargs["_links"]
+        if "_embedded" in kwargs:
+            query_params["_embedded"] = kwargs["_embedded"]
+
+        path = "/applications/{applicationId}/devices/tagKeys".format(**path_params)
+
+        return self.client.request("GET", path, params=query_params, headers=headers, body=body)
+
+    def tag_values(self, **kwargs):
+        """
+        Gets the unique tag values for the given key for devices that match the given query. Maximum 1K returned.
+
+        Authentication:
+        The client must be configured with a valid api
+        access token to call this action. The token
+        must include at least one of the following scopes:
+        all.Application, all.Application.read, all.Organization, all.Organization.read, all.User, all.User.read, devices.*, or devices.tagValues.
+
+        Parameters:
+        *  {string} applicationId - ID associated with the application
+        *  {hash} query - Device filter JSON object (https://api.losant.com/#/definitions/advancedDeviceQuery)
+        *  {string} key - The tag key to get the values for
+        *  {string} startsWith - Filter values down to those that start with the given string. Case insensitive.
+        *  {string} losantdomain - Domain scope of request (rarely needed)
+        *  {boolean} _actions - Return resource actions in response
+        *  {boolean} _links - Return resource link in response
+        *  {boolean} _embedded - Return embedded resources in response
+
+        Responses:
+        *  200 - The matching tag values (https://api.losant.com/#/definitions/tagValuesResponse)
+
+        Errors:
+        *  400 - Error if malformed request (https://api.losant.com/#/definitions/error)
+        *  404 - Error if application was not found (https://api.losant.com/#/definitions/error)
+        """
+
+        query_params = {"_actions": "false", "_links": "true", "_embedded": "true"}
+        path_params = {}
+        headers = {}
+        body = None
+
+        if "applicationId" in kwargs:
+            path_params["applicationId"] = kwargs["applicationId"]
+        if "query" in kwargs:
+            query_params["query"] = json.dumps(kwargs["query"])
+        if "key" in kwargs:
+            query_params["key"] = kwargs["key"]
+        if "startsWith" in kwargs:
+            query_params["startsWith"] = kwargs["startsWith"]
+        if "losantdomain" in kwargs:
+            headers["losantdomain"] = kwargs["losantdomain"]
+        if "_actions" in kwargs:
+            query_params["_actions"] = kwargs["_actions"]
+        if "_links" in kwargs:
+            query_params["_links"] = kwargs["_links"]
+        if "_embedded" in kwargs:
+            query_params["_embedded"] = kwargs["_embedded"]
+
+        path = "/applications/{applicationId}/devices/tagValues".format(**path_params)
+
+        return self.client.request("GET", path, params=query_params, headers=headers, body=body)
+
