@@ -47,6 +47,7 @@ class ExperienceEndpoint(object):
         Parameters:
         *  {string} applicationId - ID associated with the application
         *  {string} experienceEndpointId - ID associated with the experience endpoint
+        *  {string} includeWorkflows - If the workflows that utilize this experience endpoint should also be deleted.
         *  {string} losantdomain - Domain scope of request (rarely needed)
         *  {boolean} _actions - Return resource actions in response
         *  {boolean} _links - Return resource link in response
@@ -69,6 +70,8 @@ class ExperienceEndpoint(object):
             path_params["applicationId"] = kwargs["applicationId"]
         if "experienceEndpointId" in kwargs:
             path_params["experienceEndpointId"] = kwargs["experienceEndpointId"]
+        if "includeWorkflows" in kwargs:
+            query_params["includeWorkflows"] = kwargs["includeWorkflows"]
         if "losantdomain" in kwargs:
             headers["losantdomain"] = kwargs["losantdomain"]
         if "_actions" in kwargs:
