@@ -85,6 +85,72 @@ class FlowVersion(object):
 
         return self.client.request("DELETE", path, params=query_params, headers=headers, body=body)
 
+    def errors(self, **kwargs):
+        """
+        Get information about errors that occurred during runs of this workflow version
+
+        Authentication:
+        The client must be configured with a valid api
+        access token to call this action. The token
+        must include at least one of the following scopes:
+        all.Application, all.Application.read, all.Organization, all.Organization.read, all.User, all.User.read, flowVersion.*, or flowVersion.errors.
+
+        Parameters:
+        *  {string} applicationId - ID associated with the application
+        *  {string} flowId - ID associated with the flow
+        *  {string} flowVersionId - Version ID or version name associated with the flow version
+        *  {string} duration - Duration of time range in milliseconds
+        *  {string} end - End of time range in milliseconds since epoch
+        *  {string} limit - Maximum number of errors to return
+        *  {string} sortDirection - Direction to sort the results by. Accepted values are: asc, desc
+        *  {string} deviceId - For edge workflows, the Device ID to return workflow errors for. When not included, will be errors for all device IDs.
+        *  {string} losantdomain - Domain scope of request (rarely needed)
+        *  {boolean} _actions - Return resource actions in response
+        *  {boolean} _links - Return resource link in response
+        *  {boolean} _embedded - Return embedded resources in response
+
+        Responses:
+        *  200 - Workflow error information (https://api.losant.com/#/definitions/flowErrors)
+
+        Errors:
+        *  400 - Error if malformed request (https://api.losant.com/#/definitions/error)
+        *  404 - Error if flow version was not found (https://api.losant.com/#/definitions/error)
+        """
+
+        query_params = {"_actions": "false", "_links": "true", "_embedded": "true"}
+        path_params = {}
+        headers = {}
+        body = None
+
+        if "applicationId" in kwargs:
+            path_params["applicationId"] = kwargs["applicationId"]
+        if "flowId" in kwargs:
+            path_params["flowId"] = kwargs["flowId"]
+        if "flowVersionId" in kwargs:
+            path_params["flowVersionId"] = kwargs["flowVersionId"]
+        if "duration" in kwargs:
+            query_params["duration"] = kwargs["duration"]
+        if "end" in kwargs:
+            query_params["end"] = kwargs["end"]
+        if "limit" in kwargs:
+            query_params["limit"] = kwargs["limit"]
+        if "sortDirection" in kwargs:
+            query_params["sortDirection"] = kwargs["sortDirection"]
+        if "deviceId" in kwargs:
+            query_params["deviceId"] = kwargs["deviceId"]
+        if "losantdomain" in kwargs:
+            headers["losantdomain"] = kwargs["losantdomain"]
+        if "_actions" in kwargs:
+            query_params["_actions"] = kwargs["_actions"]
+        if "_links" in kwargs:
+            query_params["_links"] = kwargs["_links"]
+        if "_embedded" in kwargs:
+            query_params["_embedded"] = kwargs["_embedded"]
+
+        path = "/applications/{applicationId}/flows/{flowId}/versions/{flowVersionId}/errors".format(**path_params)
+
+        return self.client.request("GET", path, params=query_params, headers=headers, body=body)
+
     def get(self, **kwargs):
         """
         Retrieves information on a flow version
@@ -165,7 +231,7 @@ class FlowVersion(object):
 
         Errors:
         *  400 - Error if malformed request (https://api.losant.com/#/definitions/error)
-        *  404 - Error if device was not found (https://api.losant.com/#/definitions/error)
+        *  404 - Error if flow version was not found (https://api.losant.com/#/definitions/error)
         """
 
         query_params = {"_actions": "false", "_links": "true", "_embedded": "true"}
@@ -253,3 +319,66 @@ class FlowVersion(object):
 
         return self.client.request("PATCH", path, params=query_params, headers=headers, body=body)
 
+    def stats(self, **kwargs):
+        """
+        Get statistics about workflow runs for this workflow version
+
+        Authentication:
+        The client must be configured with a valid api
+        access token to call this action. The token
+        must include at least one of the following scopes:
+        all.Application, all.Application.read, all.Organization, all.Organization.read, all.User, all.User.read, flowVersion.*, or flowVersion.stats.
+
+        Parameters:
+        *  {string} applicationId - ID associated with the application
+        *  {string} flowId - ID associated with the flow
+        *  {string} flowVersionId - Version ID or version name associated with the flow version
+        *  {string} duration - Duration of time range in milliseconds
+        *  {string} end - End of time range in milliseconds since epoch
+        *  {string} resolution - Resolution in milliseconds
+        *  {string} deviceId - For edge workflows, the device ID to return workflow stats for. When not included, will be aggregate for all device IDs.
+        *  {string} losantdomain - Domain scope of request (rarely needed)
+        *  {boolean} _actions - Return resource actions in response
+        *  {boolean} _links - Return resource link in response
+        *  {boolean} _embedded - Return embedded resources in response
+
+        Responses:
+        *  200 - Statistics for workflow runs (https://api.losant.com/#/definitions/flowStats)
+
+        Errors:
+        *  400 - Error if malformed request (https://api.losant.com/#/definitions/error)
+        *  404 - Error if flow version was not found (https://api.losant.com/#/definitions/error)
+        """
+
+        query_params = {"_actions": "false", "_links": "true", "_embedded": "true"}
+        path_params = {}
+        headers = {}
+        body = None
+
+        if "applicationId" in kwargs:
+            path_params["applicationId"] = kwargs["applicationId"]
+        if "flowId" in kwargs:
+            path_params["flowId"] = kwargs["flowId"]
+        if "flowVersionId" in kwargs:
+            path_params["flowVersionId"] = kwargs["flowVersionId"]
+        if "duration" in kwargs:
+            query_params["duration"] = kwargs["duration"]
+        if "end" in kwargs:
+            query_params["end"] = kwargs["end"]
+        if "resolution" in kwargs:
+            query_params["resolution"] = kwargs["resolution"]
+        if "deviceId" in kwargs:
+            query_params["deviceId"] = kwargs["deviceId"]
+        if "losantdomain" in kwargs:
+            headers["losantdomain"] = kwargs["losantdomain"]
+        if "_actions" in kwargs:
+            query_params["_actions"] = kwargs["_actions"]
+        if "_links" in kwargs:
+            query_params["_links"] = kwargs["_links"]
+        if "_embedded" in kwargs:
+            query_params["_embedded"] = kwargs["_embedded"]
+
+        path = "/applications/{applicationId}/flows/{flowId}/versions/{flowVersionId}/stats".format(**path_params)
+
+        return self.client.request("GET", path, params=query_params, headers=headers, body=body)
+
