@@ -251,47 +251,6 @@ class Me(object):
 
         return self.client.request("PATCH", path, params=query_params, headers=headers, body=body)
 
-    def disconnect_twitter(self, **kwargs):
-        """
-        Disconnects the user from Twitter
-
-        Authentication:
-        The client must be configured with a valid api
-        access token to call this action. The token
-        must include at least one of the following scopes:
-        all.User, me.*, or me.disconnectTwitter.
-
-        Parameters:
-        *  {string} losantdomain - Domain scope of request (rarely needed)
-        *  {boolean} _actions - Return resource actions in response
-        *  {boolean} _links - Return resource link in response
-        *  {boolean} _embedded - Return embedded resources in response
-
-        Responses:
-        *  200 - Updated user information (https://api.losant.com/#/definitions/me)
-
-        Errors:
-        *  400 - Error if malformed request (https://api.losant.com/#/definitions/error)
-        """
-
-        query_params = {"_actions": "false", "_links": "true", "_embedded": "true"}
-        path_params = {}
-        headers = {}
-        body = None
-
-        if "losantdomain" in kwargs:
-            headers["losantdomain"] = kwargs["losantdomain"]
-        if "_actions" in kwargs:
-            query_params["_actions"] = kwargs["_actions"]
-        if "_links" in kwargs:
-            query_params["_links"] = kwargs["_links"]
-        if "_embedded" in kwargs:
-            query_params["_embedded"] = kwargs["_embedded"]
-
-        path = "/me/disconnectTwitter".format(**path_params)
-
-        return self.client.request("PATCH", path, params=query_params, headers=headers, body=body)
-
     def enable_two_factor_auth(self, **kwargs):
         """
         Enables two factor auth for the current user
