@@ -1,7 +1,7 @@
 """
 The MIT License (MIT)
 
-Copyright (c) 2018 Losant IoT, Inc.
+Copyright (c) 2020 Losant IoT, Inc.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -22,6 +22,9 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
 
+
+import json
+
 """ Module for Losant API Org wrapper class """
 # pylint: disable=C0301
 
@@ -88,7 +91,8 @@ class Org(object):
 
         Parameters:
         *  {string} orgId - ID associated with the organization
-        *  {string} summaryExclude - List of summary fields to exclude from org summary
+        *  {string} summaryExclude - Comma-separated list of summary fields to exclude from org summary
+        *  {string} summaryInclude - Comma-separated list of summary fields to include in org summary
         *  {string} losantdomain - Domain scope of request (rarely needed)
         *  {boolean} _actions - Return resource actions in response
         *  {boolean} _links - Return resource link in response
@@ -111,6 +115,8 @@ class Org(object):
             path_params["orgId"] = kwargs["orgId"]
         if "summaryExclude" in kwargs:
             query_params["summaryExclude"] = kwargs["summaryExclude"]
+        if "summaryInclude" in kwargs:
+            query_params["summaryInclude"] = kwargs["summaryInclude"]
         if "losantdomain" in kwargs:
             headers["losantdomain"] = kwargs["losantdomain"]
         if "_actions" in kwargs:
@@ -185,6 +191,8 @@ class Org(object):
         Parameters:
         *  {string} orgId - ID associated with the organization
         *  {hash} member - Object containing new member pair (https://api.losant.com/#/definitions/orgMemberPatch)
+        *  {string} summaryExclude - Comma-separated list of summary fields to exclude from org summary
+        *  {string} summaryInclude - Comma-separated list of summary fields to include in org summary
         *  {string} losantdomain - Domain scope of request (rarely needed)
         *  {boolean} _actions - Return resource actions in response
         *  {boolean} _links - Return resource link in response
@@ -207,6 +215,10 @@ class Org(object):
             path_params["orgId"] = kwargs["orgId"]
         if "member" in kwargs:
             body = kwargs["member"]
+        if "summaryExclude" in kwargs:
+            query_params["summaryExclude"] = kwargs["summaryExclude"]
+        if "summaryInclude" in kwargs:
+            query_params["summaryInclude"] = kwargs["summaryInclude"]
         if "losantdomain" in kwargs:
             headers["losantdomain"] = kwargs["losantdomain"]
         if "_actions" in kwargs:
@@ -233,6 +245,8 @@ class Org(object):
         Parameters:
         *  {string} orgId - ID associated with the organization
         *  {hash} organization - Object containing new organization properties (https://api.losant.com/#/definitions/orgPatch)
+        *  {string} summaryExclude - Comma-separated list of summary fields to exclude from org summary
+        *  {string} summaryInclude - Comma-separated list of summary fields to include in org summary
         *  {string} losantdomain - Domain scope of request (rarely needed)
         *  {boolean} _actions - Return resource actions in response
         *  {boolean} _links - Return resource link in response
@@ -255,6 +269,10 @@ class Org(object):
             path_params["orgId"] = kwargs["orgId"]
         if "organization" in kwargs:
             body = kwargs["organization"]
+        if "summaryExclude" in kwargs:
+            query_params["summaryExclude"] = kwargs["summaryExclude"]
+        if "summaryInclude" in kwargs:
+            query_params["summaryInclude"] = kwargs["summaryInclude"]
         if "losantdomain" in kwargs:
             headers["losantdomain"] = kwargs["losantdomain"]
         if "_actions" in kwargs:
@@ -377,6 +395,8 @@ class Org(object):
         Parameters:
         *  {string} orgId - ID associated with the organization
         *  {string} userId - Id of user to remove
+        *  {string} summaryExclude - Comma-separated list of summary fields to exclude from org summary
+        *  {string} summaryInclude - Comma-separated list of summary fields to include in org summary
         *  {string} losantdomain - Domain scope of request (rarely needed)
         *  {boolean} _actions - Return resource actions in response
         *  {boolean} _links - Return resource link in response
@@ -399,6 +419,10 @@ class Org(object):
             path_params["orgId"] = kwargs["orgId"]
         if "userId" in kwargs:
             query_params["userId"] = kwargs["userId"]
+        if "summaryExclude" in kwargs:
+            query_params["summaryExclude"] = kwargs["summaryExclude"]
+        if "summaryInclude" in kwargs:
+            query_params["summaryInclude"] = kwargs["summaryInclude"]
         if "losantdomain" in kwargs:
             headers["losantdomain"] = kwargs["losantdomain"]
         if "_actions" in kwargs:
