@@ -47,6 +47,7 @@ class Webhook(object):
         Parameters:
         *  {string} applicationId - ID associated with the application
         *  {string} webhookId - ID associated with the webhook
+        *  {string} includeWorkflows - If the workflows that utilize this webhook should also be deleted.
         *  {string} losantdomain - Domain scope of request (rarely needed)
         *  {boolean} _actions - Return resource actions in response
         *  {boolean} _links - Return resource link in response
@@ -69,6 +70,8 @@ class Webhook(object):
             path_params["applicationId"] = kwargs["applicationId"]
         if "webhookId" in kwargs:
             path_params["webhookId"] = kwargs["webhookId"]
+        if "includeWorkflows" in kwargs:
+            query_params["includeWorkflows"] = kwargs["includeWorkflows"]
         if "losantdomain" in kwargs:
             headers["losantdomain"] = kwargs["losantdomain"]
         if "_actions" in kwargs:
